@@ -419,7 +419,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         latest_staging_version = self.latest_staging_version
         y_predd, lower, upper, conf = [ np.nan ], np.nan, np.nan, np.nan
         lowers, uppers, confs, y_pred = [ ], [ ], [ ], [ ]
-        match_key = unit[ 'POSTCODE_AREA' ].astype(str) + unit['NUMBER_HEATED_ROOMS_e'].astype(str) 
+        match_key = unit[ 'POSTCODE_AREA' ].astype(str) + unit['PROPERTY_TYPE_e'].astype(str) 
         match_key = match_key.values[ 0 ]
 
         unit = infer_feature_types(unit)
@@ -439,7 +439,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             self.l.append(resp)
             return self
 
-        dfs = data[ (data[ 'POSTCODE_AREA' ].astype(str)==unit[ 'POSTCODE_AREA' ].astype(str).values[ 0 ]) & (data[ 'NUMBER_HEATED_ROOMS_e' ].astype(str)==unit[ 'NUMBER_HEATED_ROOMS_e' ].astype(str).values[ 0 ])]
+        dfs = data[ (data[ 'POSTCODE_AREA' ].astype(str)==unit[ 'POSTCODE_AREA' ].astype(str).values[ 0 ]) & (data[ 'PROPERTY_TYPE_e' ].astype(str)==unit[ 'PROPERTY_TYPE_e' ].astype(str).values[ 0 ])]
 
         if len(dfs) < self.min_sample_sz:
             resp = pd.DataFrame({})
