@@ -137,15 +137,19 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
 
     data = data[keep_cols]
 
-    try:
-        data['POSTCODE'] = data['FULLADRESS_e'].apply(get_postcode_from_address)
-        data['POSTCODE_OUTCODE'] = data['Postcode'].apply(get_postcodeOutcode_from_postcode)
-        data['POSTCODE_AREA'] = data['POSTCODE_OUTCODE'].apply(get_postcodeArea_from_outcode)
-    except: pass
+    if 'POSTCODE_AREA' not in data.columns:
+        try:
+            data['POSTCODE'] = data['FULLADRESS_e'].apply(get_postcode_from_address)
+            data['POSTCODE_OUTCODE'] = data['Postcode'].apply(get_postcodeOutcode_from_postcode)
+            data['POSTCODE_AREA'] = data['POSTCODE_OUTCODE'].apply(get_postcodeArea_from_outcode)
+        except: pass
 
-    # drop outliers, convert floor level to integers
-    data['Rooms'] = (data['NUMBER_HABITABLE_ROOMS_e'].astype(float) + data['NUMBER_HEATED_ROOMS_e'].astype(
-        float)) / float(2)
+    try:
+        # drop outliers, convert floor level to integers
+        data['Rooms'] = (data['NUMBER_HABITABLE_ROOMS_e'].astype(float) + data['NUMBER_HEATED_ROOMS_e'].astype(
+            float)) / float(2)
+    except:
+        data['Rooms'] = data['NUMBER_HEATED_ROOMS_e'].astype(float)
 
     data['PROPERTY_TYPE_e'] = data['PROPERTY_TYPE_e'].astype(str).replace('nan', np.nan).fillna(
         'No PROPERTY_TYPE_e').astype(str)
@@ -203,12 +207,14 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
                      'Latitude_m',
                      'Longitude_m']]
 
-    data = data.reset_index()
-    data = data.drop('index', axis=1)
-    data = data.reset_index()
-    data = data.rename({'index': 'unit_indx'}, axis=1)
-    data = data.reset_index()
-    data = data.drop('index', axis=1)
+    if 'unit_indx' not in data.columns:
+        data = data.reset_index()
+        data = data.drop('index', axis=1)
+        data = data.reset_index()
+        data = data.rename({'index': 'unit_indx'}, axis=1)
+        data = data.reset_index()
+        data = data.drop('index', axis=1)
+        
     data['TOTAL_FLOOR_AREA_e'] = data['TOTAL_FLOOR_AREA_e'].astype(float)
     data['FLOOR_LEVEL_e'] = data['FLOOR_LEVEL_e'].astype(float)
     data['NUMBER_HEATED_ROOMS_e'] = data['NUMBER_HEATED_ROOMS_e'].astype(float)
